@@ -1,6 +1,13 @@
-package MooseX::Types::DateTime::MoreCoercions;
 use strict;
 use warnings;
+package MooseX::Types::DateTime::MoreCoercions;
+BEGIN {
+  $MooseX::Types::DateTime::MoreCoercions::AUTHORITY = 'cpan:ILMARI';
+}
+# git description: v0.12-1-g531e1a2
+$MooseX::Types::DateTime::MoreCoercions::VERSION = '0.13';
+# ABSTRACT: Extensions to L<MooseX::Types::DateTime>
+# KEYWORDS: moose types constraints coercions date time datetime timestamp
 
 use Moose 0.41 ();
 use DateTime 0.4302 ();
@@ -9,12 +16,10 @@ use DateTimeX::Easy 0.085 ();
 use Time::Duration::Parse 0.06 qw(parse_duration);
 use MooseX::Types::DateTime 0.07 ();
 use MooseX::Types::Moose 0.04 qw/Num HashRef Str/;
-
 use namespace::clean 0.08;
 
-our $VERSION = '0.11';
-
 use MooseX::Types 0.04 -declare => [qw( DateTime Duration)];
+use if MooseX::Types->VERSION >= 0.42, 'namespace::autoclean';
 
 subtype DateTime, as MooseX::Types::DateTime::DateTime;
 coerce( DateTime,
@@ -25,8 +30,8 @@ coerce( DateTime,
 subtype Duration, as MooseX::Types::DateTime::Duration;
 coerce( Duration,
     @{ MooseX::Types::DateTime::Duration->coercion->type_coercion_map },
-    from Str, via { 
-        DateTime::Duration->new( 
+    from Str, via {
+        DateTime::Duration->new(
             seconds => parse_duration($_)
         );
     },
@@ -36,10 +41,18 @@ coerce( Duration,
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 MooseX::Types::DateTime::MoreCoercions - Extensions to L<MooseX::Types::DateTime>
 
+=head1 VERSION
+
+version 0.13
+
 =head1 SYNOPSIS
 
     package MyApp::MyClass;
@@ -101,12 +114,58 @@ John Napiorkowski E<lt>jjn1056 at yahoo.comE<gt>
 Broken into a separate package from L<MooseX::Types::DateTime> by Evan Carroll.
 
 Forked from L<MooseX::Types::DateTimeX> and ported back to use
-L<MooseX::Types::DateTime> by Dagfinn Ilmari MannsE<aring>ker
+L<MooseX::Types::DateTime> by Dagfinn Ilmari Mannsåker
 E<lt>ilmari@ilmari.orgE<gt>.
 
-=head1 LICENSE
+=head1 AUTHORS
 
-    Copyright (c) 2008 John Napiorkowski.
+=over 4
 
-    This program is free software; you can redistribute
-    it and/or modify it under the same terms as Perl itself.
+=item *
+
+John Napiorkowski <jjn1056@yahoo.com>
+
+=item *
+
+Dagfinn Ilmari Mannsåker <ilmari@ilmari.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2008 by John Napiorkowski.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=head1 CONTRIBUTORS
+
+=over 4
+
+=item *
+
+Dagfinn Ilmari Mannsåker <ilmari@photobox.com>
+
+=item *
+
+Evan Carroll <me+cpan@evancarroll.com>
+
+=item *
+
+Evan Carroll <me@evancarroll.com>
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+gregor herrmann <gregoa@debian.org>
+
+=item *
+
+root <root@x60s.(none)>
+
+=back
+
+=cut
